==> huaweicloudsdkcss-3.0.80-py2.py3-none-any.whl: huaweicloudsdkcss/v1/model/list_confs_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListConfsResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'confs': 'list[Confs]'
    }

    attribute_map = {
        'confs': 'confs'
    }

    def __init__(self, confs=None):
        """ListConfsResponse - a model defined in huaweicloud sdk"""
        
        super(ListConfsResponse, self).__init__()

        self._confs = None
        self.discriminator = None

        if confs is not None:
            self.confs = confs

    @property
    def confs(self):
        """Gets the confs of this ListConfsResponse.

        配置文件列表。

        :return: The confs of this ListConfsResponse.
        :rtype: list[Confs]
        """
        return self._confs

    @confs.setter
    def confs(self, confs):
        """Sets the confs of this ListConfsResponse.

        配置文件列表。

        :param confs: The confs of this ListConfsResponse.
        :type: list[Confs]
        """
        self._confs = confs

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListConfsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcss-3.0.102-py2.py3-none-any.whl: huaweicloudsdkcss/v1/model/list_confs_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListConfsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'confs': 'list[Confs]'
    }

    attribute_map = {
        'confs': 'confs'
    }

    def __init__(self, confs=None):
        """ListConfsResponse

        The model defined in huaweicloud sdk

        :param confs: 配置文件列表。
        :type confs: list[:class:`huaweicloudsdkcss.v1.Confs`]
        """
        
        super(ListConfsResponse, self).__init__()

        self._confs = None
        self.discriminator = None

        if confs is not None:
            self.confs = confs

    @property
    def confs(self):
        """Gets the confs of this ListConfsResponse.

        配置文件列表。

        :return: The confs of this ListConfsResponse.
        :rtype: list[:class:`huaweicloudsdkcss.v1.Confs`]
        """
        return self._confs

    @confs.setter
    def confs(self, confs):
        """Sets the confs of this ListConfsResponse.

        配置文件列表。

        :param confs: The confs of this ListConfsResponse.
        :type confs: list[:class:`huaweicloudsdkcss.v1.Confs`]
        """
        self._confs = confs

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListConfsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
